@@ -3,6 +3,9 @@ var group__bonding =
     [ "bond_info", "structbond__info.html", null ],
     [ "rtnl_link_bond_set_activeslave", "group__bonding.html#ga201deefd88e1410cfc2b30c5a130cce5", null ],
     [ "rtnl_link_bond_set_mode", "group__bonding.html#ga087e6f8cb20309ce2366a6188ca2a6b4", null ],
+    [ "rtnl_link_bond_set_hashing_type", "group__bonding.html#ga8b198531072c2352c8addbc7fa75c9e9", null ],
+    [ "rtnl_link_bond_set_miimon", "group__bonding.html#gab696188e65acaaf0e5ba4de7bab6662a", null ],
+    [ "rtnl_link_bond_set_min_links", "group__bonding.html#ga0dfe2f62ca42088094a961623d04069a", null ],
     [ "rtnl_link_bond_alloc", "group__bonding.html#ga50999216d86004c762f46fbb6a47aeec", null ],
     [ "rtnl_link_bond_add", "group__bonding.html#ga4f0bcc72d492b8b507b875f83b2bb115", null ],
     [ "rtnl_link_bond_enslave_ifindex", "group__bonding.html#ga307a6dacb6ab70d96d7e362f9c96e683", null ],
