@@ -1,20 +1,19 @@
 var group__cache =
 [
-    [ "Cache Implementation", "group__cache__api.html", "group__cache__api" ],
     [ "NL_CACHE_AF_ITER", "group__cache.html#ga65d7444dc6492a98457fb8a31a7df1a8", null ],
     [ "nl_cache_nitems", "group__cache.html#ga47554223760ce5293c5c3dc8bf07cac8", null ],
     [ "nl_cache_nitems_filter", "group__cache.html#ga57a3c518ce67e5e1db978a6eb039413f", null ],
     [ "nl_cache_is_empty", "group__cache.html#ga921e4e1d4781714a47ad4c00e8a3bed2", null ],
-    [ "nl_cache_get_ops", "group__cache.html#ga20673ac0b3b5717b38e71dad37e2cb93", null ],
-    [ "nl_cache_get_first", "group__cache.html#ga2d7a6e36cf61c536b0b664afa04fe001", null ],
-    [ "nl_cache_get_last", "group__cache.html#gac0767be207d9a57600939544da48c33f", null ],
-    [ "nl_cache_get_next", "group__cache.html#ga22a6394070bffe8df63b81d0cb0a4dc2", null ],
-    [ "nl_cache_get_prev", "group__cache.html#ga683817f4551540a0e035f76bb40696fb", null ],
-    [ "nl_cache_alloc", "group__cache.html#ga9520ae0f2158db3c081f34c851d92252", null ],
+    [ "nl_cache_get_ops", "group__cache.html#gaea61cecd41a075c0af54e7b85491c816", null ],
+    [ "nl_cache_get_first", "group__cache.html#ga98d2786bc76ca7cfa48307482145cdfd", null ],
+    [ "nl_cache_get_last", "group__cache.html#ga7f8fd9bb8aeae1cbdd23a059137c658b", null ],
+    [ "nl_cache_get_next", "group__cache.html#ga88cd6182ac682e2186d0d3c623195a4f", null ],
+    [ "nl_cache_get_prev", "group__cache.html#gaae8f029c4f5687940cc6b52001414ffc", null ],
+    [ "nl_cache_alloc", "group__cache.html#ga81ea211e50b58012f8b554deeb7fb0ba", null ],
     [ "nl_cache_alloc_and_fill", "group__cache.html#ga93fdf77495c6e7469ca1d904ab39f73e", null ],
     [ "nl_cache_alloc_name", "group__cache.html#gac814b6786d697e3cc4affc1b26a1082a", null ],
-    [ "nl_cache_subset", "group__cache.html#ga5ea44d636362abb91193084ec71a2668", null ],
-    [ "nl_cache_clone", "group__cache.html#ga70fcfa02d45ac7a0666ffd22bd672d98", null ],
+    [ "nl_cache_subset", "group__cache.html#gabdb776e28658e0eddc3a968c4ec98f74", null ],
+    [ "nl_cache_clone", "group__cache.html#gadc41a539efefcbd093227c83d3414882", null ],
     [ "nl_cache_clear", "group__cache.html#gad22be4bd392afc8daca60a80f24a277b", null ],
     [ "nl_cache_get", "group__cache.html#ga56d5d8e6268b4e6608141d6bea58cdf1", null ],
     [ "nl_cache_free", "group__cache.html#ga530c896db26d72001d011114b1e6cfaa", null ],
@@ -24,10 +23,12 @@ var group__cache =
     [ "nl_cache_set_arg1", "group__cache.html#ga281b7042d76dbdc704dc0a47c7cd83f0", null ],
     [ "nl_cache_set_arg2", "group__cache.html#gadfc11eb41b9d48468ea0c88f4c9f22a9", null ],
     [ "nl_cache_set_flags", "group__cache.html#ga19e5aa1e6d23876b250611bc14d95a32", null ],
+    [ "nl_cache_pickup_checkdup", "group__cache.html#gaab3806e3f27fec551ebc058d98914f1f", null ],
     [ "nl_cache_pickup", "group__cache.html#ga6259b43583b20927adf461300cabca12", null ],
     [ "nl_cache_parse_and_add", "group__cache.html#ga6fb98385ab2fb543b1720ce84ab559db", null ],
     [ "nl_cache_refill", "group__cache.html#ga10aacd9aef738dbf9e0e5967272999de", null ],
-    [ "nl_cache_search", "group__cache.html#ga746f17a6442477f1dbd6513de884000a", null ],
+    [ "nl_cache_search", "group__cache.html#ga32a6f291a28825f8a832ccf6b473b70f", null ],
+    [ "nl_cache_find", "group__cache.html#ga4baa84e841dcfd07c61cc0216f9be493", null ],
     [ "nl_cache_mark_all", "group__cache.html#gaf72b8b81e5b84440bb7534c8cd00b9d2", null ],
     [ "nl_cache_dump", "group__cache.html#ga8e7a06ddf0139ee1c9304721793772d1", null ],
     [ "nl_cache_dump_filter", "group__cache.html#ga5d7082fb0e848926ef73bd531187d50f", null ],
