@@ -5,16 +5,16 @@ var group__idiag =
     [ "Inet Diag Requests", "group__idiagnl__req.html", null ],
     [ "Inet Diag TCP Vegas Info", "group__idiagnl__vegasinfo.html", null ],
     [ "IDIAG_SS_ALL", "group__idiag.html#ga3cfb60c0d7ec3e8663ba513987b0407e", null ],
-    [ "IDIAG_ATTR_ALL", "group__idiag.html#gacce3cc693ceb5aa5339395713a56068c", null ],
+    [ "IDIAGNL_SS_ALL", "group__idiag.html#ga1ec769fb284fe10b8892ede40d7d3a7b", null ],
     [ "idiagnl_connect", "group__idiag.html#ga8e6da0618c06c40382fb0c5564db27a6", null ],
     [ "idiagnl_send_simple", "group__idiag.html#gac845868805173444d33e2a3c0c442032", null ],
-    [ "idiagnl_state2str", "group__idiag.html#ga01e9562e486e448dd7a2a5c2b938a107", null ],
+    [ "idiagnl_state2str", "group__idiag.html#gac16059887ab151aded97f1d8c6a217eb", null ],
     [ "idiagnl_str2state", "group__idiag.html#ga67edaca6d7e70d5d57a66ec57dafb88a", null ],
-    [ "idiagnl_timer2str", "group__idiag.html#gaa26df72639aed858d45ebbda6a597b5e", null ],
+    [ "idiagnl_timer2str", "group__idiag.html#ga6c2df036657f16d3492ba513c099814a", null ],
     [ "idiagnl_str2timer", "group__idiag.html#ga60deff8658ccc1877af6ed2d04bc40c1", null ],
-    [ "idiagnl_attrs2str", "group__idiag.html#ga7b9f442e50dbdf9ab6f1c0ad7000109e", null ],
-    [ "idiagnl_tcpstate2str", "group__idiag.html#ga7c1feaad57efc4c48adaeeac56335f2e", null ],
-    [ "idiagnl_tcpopts2str", "group__idiag.html#ga726e00b0ec70dffdae9c2f5a4e4c1be0", null ],
-    [ "idiagnl_shutdown2str", "group__idiag.html#ga8ab9262c214f92d7680cb191e15acfcc", null ],
-    [ "idiagnl_exts2str", "group__idiag.html#gac5a1653ad0b36cb1982b6cd2c96e1925", null ]
+    [ "idiagnl_attrs2str", "group__idiag.html#gae86f6c8c8493069da18f207ec8889aad", null ],
+    [ "idiagnl_exts2str", "group__idiag.html#gad40e1d1452fab7a6500e1dc24839b140", null ],
+    [ "idiagnl_tcpstate2str", "group__idiag.html#gaf01485e3103e5369cd0f476ff05e0812", null ],
+    [ "idiagnl_tcpopts2str", "group__idiag.html#gaf66af077334bd63a6fa5bc6b4627a0e3", null ],
+    [ "idiagnl_shutdown2str", "group__idiag.html#gab343b032a66d0db4beb7adc036b3287a", null ]
 ];
\ No newline at end of file
