@@ -4,18 +4,27 @@ var group__link =
     [ "Bridging", "group__bridge.html", "group__bridge" ],
     [ "CAN", "group__can.html", "group__can" ],
     [ "Dummy", "group__dummy.html", null ],
+    [ "Geneve", "group__geneve.html", "group__geneve" ],
+    [ "IP6GRE", "group__ip6gre.html", "group__ip6gre" ],
     [ "IP6TNL", "group__ip6tnl.html", "group__ip6tnl" ],
+    [ "IP6VTI", "group__ip6vti.html", "group__ip6vti" ],
     [ "IPGRE", "group__ipgre.html", "group__ipgre" ],
     [ "IPIP", "group__ipip.html", "group__ipip" ],
     [ "IPVLAN", "group__ipvlan.html", "group__ipvlan" ],
     [ "IPVTI", "group__ipvti.html", "group__ipvti" ],
     [ "Intermediate Functional Block", "group__ifb.html", null ],
     [ "Link Modules API", "group__link__API.html", "group__link__API" ],
-    [ "MACVLAN", "group__macvlan.html", "group__macvlan" ],
+    [ "MACVLAN/MACVTAP", "group__macvlan.html", "group__macvlan" ],
+    [ "MACsec", "group__macsec.html", "group__macsec" ],
+    [ "PPP", "group__ppp.html", "group__ppp" ],
     [ "SIT", "group__sit.html", "group__sit" ],
+    [ "SRIOV", "group__sriov.html", "group__sriov" ],
+    [ "Team", "group__team.html", "group__team" ],
     [ "VETH", "group__veth.html", "group__veth" ],
     [ "VLAN", "group__vlan.html", "group__vlan" ],
+    [ "VRF", "group__vrf.html", "group__vrf" ],
     [ "VXLAN", "group__vxlan.html", "group__vxlan" ],
+    [ "XFRMI", "group__xfrmi.html", "group__xfrmi" ],
     [ "rtnl_link", "structrtnl__link.html", null ],
     [ "rtnl_link_stat_id_t", "group__link.html#gabe368ecaa2f41e8392325b8060862ba6", [
       [ "RTNL_LINK_RX_PACKETS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6ae24e248204a9622dcc1d3ca765e4ff2c", null ],
@@ -80,14 +89,17 @@ var group__link =
       [ "RTNL_LINK_IP6_NOECTPKTS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a9ea1025543be09acdf5ad96227dfa5d6", null ],
       [ "RTNL_LINK_IP6_ECT1PKTS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6ac6306b0fc48389db440aea0f5fb5f7c0", null ],
       [ "RTNL_LINK_IP6_ECT0PKTS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a0cef9de8266916162c6e242b1e950a4f", null ],
-      [ "RTNL_LINK_IP6_CEPKTS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a4cfaee4676aad12a62f5977070028484", null ]
+      [ "RTNL_LINK_IP6_CEPKTS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a4cfaee4676aad12a62f5977070028484", null ],
+      [ "RTNL_LINK_RX_NOHANDLER", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a6dbb2cde7fb56a637be417cd0151449a", null ],
+      [ "RTNL_LINK_REASM_OVERLAPS", "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6a0dbde66784affe342ea9cd39472ea325", null ]
     ] ],
+    [ "rtnl_link_alloc_cache_flags", "group__link.html#gaa38fce4b34b6c84f9f84174c09764b2e", null ],
     [ "rtnl_link_alloc_cache", "group__link.html#ga8fdeaee0a6f872d19e72cd77c141ce73", null ],
-    [ "rtnl_link_get", "group__link.html#ga2a3657b69c47c9e3ab809cac73bf0986", null ],
-    [ "rtnl_link_get_by_name", "group__link.html#ga1d583e4f0b43c89d854e5e681a529fad", null ],
+    [ "rtnl_link_get", "group__link.html#ga9c88cc572d0d737ea2f9370c45d4f017", null ],
+    [ "rtnl_link_get_by_name", "group__link.html#ga89feb39f7f98a0c308116c60ea211526", null ],
     [ "rtnl_link_build_get_request", "group__link.html#gaf0009632298406b7f1c1ccb5186d1eb8", null ],
     [ "rtnl_link_get_kernel", "group__link.html#ga96807a247568145dd99f351ded0ec7cb", null ],
-    [ "rtnl_link_i2name", "group__link.html#ga66328cb096fb4d21499775e75089109d", null ],
+    [ "rtnl_link_i2name", "group__link.html#gac1af6b95764928a570861d9b2937adbe", null ],
     [ "rtnl_link_name2i", "group__link.html#ga8de66ce556b6d23f045fbc6079d547ed", null ],
     [ "rtnl_link_build_add_request", "group__link.html#ga73a9ad02daafd2051e97baf9cd995a35", null ],
     [ "rtnl_link_add", "group__link.html#ga010cb3c6c598f7a60f97b67b8df9b227", null ],
@@ -95,16 +107,16 @@ var group__link =
     [ "rtnl_link_change", "group__link.html#gaff7c3644e10230ba3449bc35a064e935", null ],
     [ "rtnl_link_build_delete_request", "group__link.html#gab78ac08b353c159b69282cd25185766a", null ],
     [ "rtnl_link_delete", "group__link.html#ga591bcb3fbb7a19a4f40cfd45d060aede", null ],
-    [ "rtnl_link_alloc", "group__link.html#gae7123d57288bfe90dc405cb67c72615d", null ],
+    [ "rtnl_link_alloc", "group__link.html#ga30f2f032a6ce6604eb01978c1d62994a", null ],
     [ "rtnl_link_put", "group__link.html#gad4c047c313cc2d6b84943707f37509c4", null ],
     [ "rtnl_link_set_name", "group__link.html#ga7cce5e6bea4df62c78948e94398ec6f9", null ],
-    [ "rtnl_link_get_name", "group__link.html#ga2bea251a28c71f160230b44a7ec79763", null ],
+    [ "rtnl_link_get_name", "group__link.html#ga9ce15fdb7b0f3c065f247538347e5cdb", null ],
     [ "rtnl_link_set_group", "group__link.html#ga93d589812952193573584da4bf81e719", null ],
     [ "rtnl_link_get_group", "group__link.html#ga4cee184275214c9e5f21901e9a31cf31", null ],
     [ "rtnl_link_set_addr", "group__link.html#ga31fef8ebdb0b127dba77e5c0e79a8c9b", null ],
-    [ "rtnl_link_get_addr", "group__link.html#ga02bd3a6ac530a51220f0923c6e5e5996", null ],
+    [ "rtnl_link_get_addr", "group__link.html#gaf2e2eb2face11adba278982322248394", null ],
     [ "rtnl_link_set_broadcast", "group__link.html#ga01d020131dfc82276a734d98db6a49af", null ],
-    [ "rtnl_link_get_broadcast", "group__link.html#ga06b40fbe8e5bf9f7ee161ac2c51217b0", null ],
+    [ "rtnl_link_get_broadcast", "group__link.html#ga5a9e829c8c7408ebd23c0586d61556c3", null ],
     [ "rtnl_link_set_flags", "group__link.html#ga9a43f1fdc2397eedeb7190e9ea0b4e47", null ],
     [ "rtnl_link_unset_flags", "group__link.html#ga40c02d4d30f07243093faa3279f57ed3", null ],
     [ "rtnl_link_get_flags", "group__link.html#gafcf6bb7515e5fa4915ec0194b046a4af", null ],
@@ -124,32 +136,38 @@ var group__link =
     [ "rtnl_link_get_master", "group__link.html#ga0efbecffaca6d12e029e023524d17fbc", null ],
     [ "rtnl_link_set_carrier", "group__link.html#ga02314a373d30e7534afc8fb9907c67fc", null ],
     [ "rtnl_link_get_carrier", "group__link.html#gaca6eb0b6da5e6c38d5237d20500e8a6c", null ],
+    [ "rtnl_link_get_carrier_changes", "group__link.html#gaf42d691a912f8e68a3a2ae859030c613", null ],
     [ "rtnl_link_set_operstate", "group__link.html#gab87182565798e51c151097d72768492c", null ],
     [ "rtnl_link_get_operstate", "group__link.html#ga5881f6b39e545bbca94c307b71962e90", null ],
     [ "rtnl_link_set_linkmode", "group__link.html#ga4742bdbe9e75ce816ff1d940d6f5ec0e", null ],
     [ "rtnl_link_get_linkmode", "group__link.html#ga0424ab2b9ee65104b409695e6d6b65c3", null ],
-    [ "rtnl_link_get_ifalias", "group__link.html#gac1b599e15f5fe941281723360fe8af4e", null ],
+    [ "rtnl_link_get_ifalias", "group__link.html#gadffd8eea15ce2e3350a842209adf0477", null ],
     [ "rtnl_link_set_ifalias", "group__link.html#ga6307c4ef261f91bb2a0e530b020aea5d", null ],
     [ "rtnl_link_set_qdisc", "group__link.html#ga9c6a0c9b0d439afaf55b35775f8b2693", null ],
-    [ "rtnl_link_get_qdisc", "group__link.html#ga62c055550426d189f723d9a03f8677f9", null ],
+    [ "rtnl_link_get_qdisc", "group__link.html#ga8087cba9daf19eb66eef6acddfd52f01", null ],
     [ "rtnl_link_get_num_vf", "group__link.html#ga5c704e61b158a1a4b54430717157f672", null ],
     [ "rtnl_link_get_stat", "group__link.html#ga0c0c6a88a7113d7727c647c003bb6fab", null ],
     [ "rtnl_link_set_stat", "group__link.html#ga9ecc6200058764b01df84c1a479fb546", null ],
     [ "rtnl_link_set_type", "group__link.html#gad9f953f44e65c3deb519edad1344fb71", null ],
-    [ "rtnl_link_get_type", "group__link.html#ga30868550fe31fa040653aa52c171cdc5", null ],
+    [ "rtnl_link_get_type", "group__link.html#ga7f00e216e9779ea11b25b391dbcdb024", null ],
+    [ "rtnl_link_set_slave_type", "group__link.html#ga5cec4fbac79ed555de5e306d3fd2e424", null ],
+    [ "rtnl_link_get_slave_type", "group__link.html#ga54b51f0a9f3d4d9b851b97778dea2f84", null ],
     [ "rtnl_link_set_promiscuity", "group__link.html#gabb8d59e73563553d4dd64ab0b20ff852", null ],
     [ "rtnl_link_get_promiscuity", "group__link.html#ga677414c60bafcc0a598e08d458b58ed6", null ],
     [ "rtnl_link_set_num_tx_queues", "group__link.html#ga6f54a699e6ea6216918a5cf35398b1f0", null ],
     [ "rtnl_link_get_num_tx_queues", "group__link.html#ga4bdca1d925f79c7bd08e6ebc729d3f2a", null ],
     [ "rtnl_link_set_num_rx_queues", "group__link.html#ga84d340783b45e8a03889b20eb4e05228", null ],
     [ "rtnl_link_get_num_rx_queues", "group__link.html#ga202c65c18d9708af6eb29f2a68dc4b8c", null ],
-    [ "rtnl_link_get_phys_port_id", "group__link.html#ga4a78b3daafc1a7c2805314241d30afa2", null ],
+    [ "rtnl_link_get_gso_max_segs", "group__link.html#gabe5e84651f8d5a7644658f7e889f816d", null ],
+    [ "rtnl_link_get_gso_max_size", "group__link.html#gae0ffc1b177e7a9ce6136eafefeab6e9e", null ],
+    [ "rtnl_link_get_phys_port_id", "group__link.html#ga533f575b85ec7be1741c9f3b23ce0bce", null ],
+    [ "rtnl_link_get_phys_port_name", "group__link.html#ga5e854dbd4a2b8fcbd9321a88bede79c6", null ],
     [ "rtnl_link_enslave_ifindex", "group__link.html#gab5bb2464cf64a566db03d5ce8e11d80e", null ],
     [ "rtnl_link_enslave", "group__link.html#gab97ffb9d3b8e9899e6a9d1a31ef2ecb5", null ],
     [ "rtnl_link_release_ifindex", "group__link.html#ga289ee60ccfe070649d702b007f68b94c", null ],
     [ "rtnl_link_release", "group__link.html#ga00fd70d9a966b66cefcf4d716dc8caa0", null ],
     [ "rtnl_link_set_info_type", "group__link.html#gadddd34902ec52fa8674f66a2cd99fa9f", null ],
-    [ "rtnl_link_get_info_type", "group__link.html#gaae3e6282f5a38076e05ba596a12b4280", null ],
+    [ "rtnl_link_get_info_type", "group__link.html#gaa71f3239aadc7cce5a633f06a176dde8", null ],
     [ "rtnl_link_set_weight", "group__link.html#ga620a899abab144ac472405706c3159a6", null ],
     [ "rtnl_link_get_weight", "group__link.html#ga203d15a3c54d628f09b1b9b8144c37d6", null ]
 ];
\ No newline at end of file
