@@ -1,5 +1,9 @@
 var NAVTREEINDEX2 =
 {
+"group__ip6gre.html#gadd846d1c62573aff1843267e974ceba8":[11,7,2,5,7],
+"group__ip6gre.html#gae809475a9be71674190a152652c791be":[11,7,2,5,20],
+"group__ip6gre.html#gaf32bd37e415d08806d06481348a2e22c":[11,7,2,5,1],
+"group__ip6gre.html#gaf9c1a9f222e35e3462d76d79f98fbd97":[11,7,2,5,16],
 "group__ip6tnl.html":[11,7,2,6],
 "group__ip6tnl.html#ga03dae9c04d7baf43ddf0f9dd6bce057a":[11,7,2,6,7],
 "group__ip6tnl.html#ga047e96eeea50862b73ba5282606b69ce":[11,7,2,6,20],
@@ -245,9 +249,5 @@ var NAVTREEINDEX2 =
 "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6ae9f6861a714c37819e665f6b419d9d16":[11,7,2,26,44],
 "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6aeb1d3f00638703b01f51cc373a4a44b9":[11,7,2,26,46],
 "group__link.html#ggabe368ecaa2f41e8392325b8060862ba6af291d40ea4bf0b848f05662a2d1848f6":[11,7,2,26,40],
-"group__link.html#ggabe368ecaa2f41e8392325b8060862ba6af59bc80bacbb42748c6a1f73049d9207":[11,7,2,26,39],
-"group__link__API.html":[11,7,2,13],
-"group__link__API.html#ga00f22aa2bb8b24e04b3c3ae4b0e31a55":[11,7,2,13,7],
-"group__link__API.html#ga0de293a3904c8db13c282b941c55aa16":[11,7,2,13,4],
-"group__link__API.html#ga1ff7886f3e4b81fbafce95ff99d03b0f":[11,7,2,13,8]
+"group__link.html#ggabe368ecaa2f41e8392325b8060862ba6af59bc80bacbb42748c6a1f73049d9207":[11,7,2,26,39]
 };
